require 'spec_helper'

module Parsefiles

  describe Folders do

    context "when testing folder locations" do

      let(:options) {{'start_date' => '06-27-2014', 'end_date' => '06-29-2014'}}

      it "returns the folder location properly when a trailing slash is missing" do
        test = Folders.new '/var/log', options
        expect(test.folder).to eq '/var/log/*.{txt,log,gz}'
      end

      it "returns the folder location properly when their is a trailing slash" do
        test = Folders.new '/var/log/', options
        expect(test.folder).to eq '/var/log/*.{txt,log,gz}'
      end

      it "returns a single file name when a file name is passed in" do
        test = Folders.new 'test.log', options
        expect(test.folder).to eq './test.log'
      end
    end

    context "when testing with start_date and end_date passed in" do

      let(:options) {{'start_date' => '06-27-2014', 'end_date' => '06-29-2014'}}
      let(:folder) {Folders.new './spec/fixtures/', options}

      it "returns a list of files with date given a parent folder" do
        output = [["./spec/fixtures/testfile.txt", 1406615852], ["./spec/fixtures/testfile2.txt", 1404000016], ["./spec/fixtures/compressed.tar.gz", 1407343892]]
        expect(folder.files).to eq output
      end

      it "returns a list of files within a given date range" do
        output = ['./spec/fixtures/testfile2.txt']
        files = folder.get_files_in_range
        expect(files).to eq output
      end

      it "calculates the start date based on days back attribute" do
        allow(Date).to receive(:today).and_return(Date.parse('2014-07-20'))
        expect(folder.calc_start_date 2).to eq '07-18-2014'
      end

      it "returns the start date from options if days back option is nil" do
        expect(folder.get_start_date).to eq '06-27-2014'
      end

    end

    context "when testing with days_back passed in" do

      let(:options) {{"days_back"=>2}}
      let(:folder) {Folders.new './spec/fixtures/', options}

      it "returns the caculated start date if days_back is set" do
        allow(folder).to receive(:days_back).and_return("07-14-2014")
        expect(folder.get_start_date).to eq '07-14-2014'
      end

    end

  end
end
